@@ -838,6 +838,14 @@ static const char *product_names[] =
 	NULL
 };
 
+static gboolean product_net[] =
+{
+	FALSE,
+	TRUE,
+	TRUE,
+	NULL
+};
+
 
 static gboolean 
 visor_devices_in (GIOChannel *io_channel,
@@ -846,7 +854,7 @@ visor_devices_in (GIOChannel *io_channel,
 	GPilotDevice *device;
 	GList *l;
 	int i;
-	gboolean visor_exists = FALSE;
+	gboolean visor_exists = FALSE, visor_net = TRUE;
 	char line[256]; /* this is more than enough to fit any line from 
 			 * /proc/bus/usb/devices */
 
@@ -859,7 +867,7 @@ visor_devices_in (GIOChannel *io_channel,
 	if (context->paused) 
 		return FALSE;
 
-	/* Check /proc/bus/usb/devices for a visor */
+	/* Check /proc/bus/usb/devices for a usb device */
 	f = fopen ("/proc/bus/usb/devices", "r");
 	
 	while (fgets (line, 255, f) != NULL && !visor_exists) {
@@ -869,8 +877,10 @@ visor_devices_in (GIOChannel *io_channel,
 		for (i = 0; product_names[i] != NULL; i++) {
 			if (!strncmp (line + strlen ("S:  Product="), 
 				      product_names[i], 
-				      strlen (product_names[i])))
+				      strlen (product_names[i]))) {
 				visor_exists = TRUE;
+				visor_net = product_net[i];
+			}
 		}
 	}
 	
@@ -881,10 +891,16 @@ visor_devices_in (GIOChannel *io_channel,
 		while (l) {
 			device = l->data;
 			if (device->type == PILOT_DEVICE_USB_VISOR) {
+				if (!visor_net)
+					device->type = PILOT_DEVICE_SERIAL;
+				
 				/* just try to synch.  Until I can talk to 
 				 * the kernel guys this is the best way to 
                                  * go. */
 				sync_device (device, context);
+
+				if (!visor_net)
+					device->type = PILOT_DEVICE_USB_VISOR;
 			}
 			l = l->next;
 		}
@@ -1107,11 +1123,6 @@ dump_build_info ()
 #ifdef WITH_VFS
 	str = g_string_append (str, "[VFS] ");
 #endif
-#ifdef USING_OAF
-	str = g_string_append (str, "[OAF] ");
-#else
-	str = g_string_append (str, "[GOAD] ");
-#endif
 #ifdef WITH_USB_VISOR
 	str = g_string_append (str, "[USB] ");
 #endif
